==> bribery-0.3.0%2B1.21.4-fabric-sources.jar: dev/spagurder/bribery/mixin/LivingEntityMixin.java <==
package dev.spagurder.bribery.mixin;

import dev.spagurder.bribery.config.Config;
import dev.spagurder.bribery.core.BribeHandler;
import net.minecraft.class_1282;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1309.class)
public class LivingEntityMixin {
    //? <=1.21.1 {
    /*@Inject(method = "hurt", at = @At("HEAD"), cancellable = true)
    public void beforeHurt(DamageSource damageSource, float f, CallbackInfoReturnable<Boolean> cir) {
    *///?} else {
    @Inject(method = "hurtServer", at = @At("HEAD"), cancellable = true)
    public void beforeHurt(
            class_3218 serverLevel, class_1282 damageSource,
            float f, CallbackInfoReturnable<Boolean> cir) {
    //?}
        if (damageSource.method_5529() instanceof class_1309 damagingEntity) {
            if (damagingEntity instanceof class_3222 player) {
                class_1309 entity = (class_1309)(Object) this;
                if (player.method_5715()) {
                    class_1799 bribe = player.method_6047();
                    if (Config.CURRENCY_CONFIGS.containsKey(bribe.method_7909())) {
                        cir.setReturnValue(
                                BribeHandler.handle(entity, player, bribe)
                        );
                        return;
                    }
                }
                BribeHandler.cancel(entity, player);
            }
        }
    }

}

==> bribery-0.4.0%2B1.20.4-fabric-sources.jar: dev/spagurder/bribery/mixin/LivingEntityMixin.java <==
package dev.spagurder.bribery.mixin;

import dev.spagurder.bribery.config.Config;
import dev.spagurder.bribery.core.BribeHandler;
import net.minecraft.class_1282;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_3222;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1309.class)
public class LivingEntityMixin {
    //? <=1.21.1 {
    @Inject(method = "hurt", at = @At("HEAD"), cancellable = true)
    public void beforeHurt(class_1282 damageSource, float f, CallbackInfoReturnable<Boolean> cir) {
    //?} else {
    /*@Inject(method = "hurtServer", at = @At("HEAD"), cancellable = true)
    public void beforeHurt(
            ServerLevel serverLevel, DamageSource damageSource,
            float f, CallbackInfoReturnable<Boolean> cir) {
    *///?}
        if (damageSource.method_5529() instanceof class_1309 damagingEntity) {
            if (damagingEntity instanceof class_3222 player) {
                class_1309 entity = (class_1309)(Object) this;
                if (player.method_5715()) {
                    class_1799 bribe = player.method_6047();
                    if (Config.CURRENCY_CONFIGS.containsKey(bribe.method_7909())) {
                        cir.setReturnValue(
                                BribeHandler.handle(entity, player, bribe)
                        );
                        return;
                    }
                }
                BribeHandler.cancel(entity, player);
            }
        }
    }

}
